from .catenator import Catenator

__project__ = "catenator"
__version__ = "0.2.6"
__author__ = "Philip Orange"
__email__ = "git@philiporange.com"
__description__ = "A Python tool for concatenating code."
__all__ = ["Catenator"]
